From 24472982c953b7d499b1c7a571c9835b9921e28e Mon Sep 17 00:00:00 2001
From: tcarver <tjc>
Date: Wed, 12 Sep 2012 12:15:11 +0100
Subject: [PATCH] look for /pseudogene as well as /pseudo

---
 uk/ac/sanger/artemis/components/SelectMenu.java | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

diff --git a/uk/ac/sanger/artemis/components/SelectMenu.java b/uk/ac/sanger/artemis/components/SelectMenu.java
index a145cdd62..8c4a36587 100644
--- a/uk/ac/sanger/artemis/components/SelectMenu.java
+++ b/uk/ac/sanger/artemis/components/SelectMenu.java
@@ -279,14 +279,16 @@ public class SelectMenu extends SelectionMenu
     add(select_by_key_item);
 
     select_non_pseudo_cds_item =
-      new JMenuItem("CDS Features without /pseudo");
+      new JMenuItem("CDS Features without /pseudogene");
     select_non_pseudo_cds_item.addActionListener(new ActionListener()
     {
       public void actionPerformed(ActionEvent event)
       {
-        // select all CDS features that do not have the /pseudo qualifier
-        final FeatureKeyQualifierPredicate predicate =
-          new FeatureKeyQualifierPredicate(Key.CDS, "pseudo", false);
+        // select all CDS features that do not have the /pseudo  or /pseudogene qualifier
+        final FeaturePredicateConjunction predicate = new FeaturePredicateConjunction(
+            new FeatureKeyQualifierPredicate(Key.CDS, "pseudo", false),
+            new FeatureKeyQualifierPredicate(Key.CDS, "pseudogene", false),
+            FeaturePredicateConjunction.AND);
 
         clearSelection();
 
-- 
GitLab